#ifndef ALIPHOS_H
#define ALIPHOS_H
/* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice     */
/* $Id$ */

//_________________________________________________________________________
//  Base Class for PHOS     
//                  
//*-- Author: Laurent Aphecetche & Yves Schutz (SUBATECH)

// --- ROOT system ---
#include "TString.h"

// --- AliRoot header files ---

#include "AliDetector.h"

class AliPHOSGeometry ; 

class AliPHOS : public AliDetector {

 public:

  AliPHOS() ;
  AliPHOS(const char* name, const char* title="");
  AliPHOS(const AliPHOS & phos) {
    // cpy ctor: no implementation yet
    // requested by the Coding Convention
    abort() ; 
  }
  virtual ~AliPHOS() ; 
  virtual void   AddHit(Int_t, Int_t*, Float_t *) {
    // do not use this definition but the one below
    abort() ; 
  }
  virtual void   AddHit( Int_t shunt, Int_t primary, Int_t track, Int_t id, Float_t *hits ) = 0 ;   
  virtual void   CreateMaterials() ;                     
  TObjArray *    EmcRecPoints() const {    return fEmcRecPoints ;  }     // Getting list of RecPoints 
  virtual  AliPHOSGeometry * GetGeometry() = 0 ;

  Int_t   IsVersion(void) const { return -1 ; } 
  TObjArray     * PpsdRecPoints() const {    return  fPpsdRecPoints ;  } 
  virtual void    SetTreeAddress();                
  TClonesArray  * RecParticles() const {    return fRecParticles ;  }    // Getting list of RecParticles
  TClonesArray  * SDigits() const {return fSDigits;}

  TClonesArray  * TrackSegments() const {    return fTrackSegments ;
  }
  virtual TString Version() {return TString(" ") ; } 
 
  AliPHOS & operator = (const AliPHOS & rvalue)  {
    // assignement operator requested by coding convention
    // but not needed
    abort() ;
    return *this ; 
  }
 
protected:
  TClonesArray                           *fSDigits      ; // List of summable digits
  TObjArray                              *fEmcRecPoints ; // The RecPoints (clusters) list in EMC 
  TObjArray                              *fPpsdRecPoints ;// The RecPoints (clusters) list in PPSD (veto)
  TClonesArray                           *fTrackSegments ;// The TrackSegment list in PHOS
  TClonesArray                           *fRecParticles ; // The reconstructed particles list in PHOS

  ClassDef(AliPHOS,2) // Photon Spectrometer Detector (base class)

} ;

#endif // ALIPHOS_H
